Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'spec/services/notes/create_service_spec.rb')
-rw-r--r--spec/services/notes/create_service_spec.rb10
1 files changed, 4 insertions, 6 deletions
diff --git a/spec/services/notes/create_service_spec.rb b/spec/services/notes/create_service_spec.rb
index 37318d76586..4922e72b7a4 100644
--- a/spec/services/notes/create_service_spec.rb
+++ b/spec/services/notes/create_service_spec.rb
@@ -134,8 +134,7 @@ RSpec.describe Notes::CreateService do
context 'in a merge request' do
let_it_be(:project_with_repo) { create(:project, :repository) }
let_it_be(:merge_request) do
- create(:merge_request, source_project: project_with_repo,
- target_project: project_with_repo)
+ create(:merge_request, source_project: project_with_repo, target_project: project_with_repo)
end
context 'noteable highlight cache clearing' do
@@ -181,8 +180,7 @@ RSpec.describe Notes::CreateService do
it 'does not clear cache when note is not the first of the discussion' do
prev_note =
- create(:diff_note_on_merge_request, noteable: merge_request,
- project: project_with_repo)
+ create(:diff_note_on_merge_request, noteable: merge_request, project: project_with_repo)
reply_opts =
opts.merge(in_reply_to_discussion_id: prev_note.discussion_id,
type: 'DiffNote',
@@ -408,9 +406,9 @@ RSpec.describe Notes::CreateService do
expect(issuable.draft?).to eq(can_use_quick_action)
}
),
# Remove draft status
QuickAction.new(
- action_text: "/draft",
+ action_text: "/ready",
before_action: -> {
issuable.reload.update!(title: "Draft: title")
},
@@ -408,9 +406,9 @@ RSpec.describe Notes::CreateService do
}
),
- # Remove draft status
+ # Remove draft (set ready) status
QuickAction.new(